@@ -1,62 +1,57 @@
 package App::revealup::cli::serve;
-use strict;
-use warnings;
+use App::revealup::base;
 use Getopt::Long qw/GetOptionsFromArray/;
 use File::ShareDir qw/dist_dir/;
 use Path::Tiny qw/path/;
-use Text::MicroTemplate qw/render_mt/;
 use Plack::Runner;
 use Pod::Usage;
 use App::revealup::util;
+use App::revealup::builder;
 
-my $_plack_port = 5000;
-my $_dry_run = 0;
-my $_theme;
-my $_theme_path = '';
-my $_transition = 'default';
-my $_size = { width => 960, height => 700 };
+has 'plack_port' => 5000;
+has 'dry_run' => 0;
+has 'theme';
+has 'transition';
+has 'width';
+has 'height';
+has 'theme_path';
 
 sub run {
     my ($self, @args) = @_;
+    my $opt;
     parse_options(
         \@args,
-        'p|port=s' => \$_plack_port,
-        'theme=s' => \$_theme,
-        'transition=s' => \$_transition,
-        'width=i' => \$_size->{width},
-        'height=i' => \$_size->{height},
-        '_dry-run' => \$_dry_run
+        'p|port=s' => \$opt->{plack_port},
+        'theme=s' => \$opt->{theme},
+        'transition=s' => \$opt->{transition},
+        'width=i' => \$opt->{width},
+        'height=i' => \$opt->{height},
+        '_dry-run' => \$opt->{dry_run},
     );
 
+    for my $key (keys %$opt) {
+        $self->$key( $opt->{$key} );
+    }
+    
     my $filename = shift @args;
-    if( !$filename || !path($filename)->exists ) {
-        pod2usage( { -input => __FILE__, -verbose => 2, -output => \*STDERR } );
+    my $builder = App::revealup::builder->new(
+        filename => $filename || '',
+        theme => $self->theme || '',
+        transition => $self->transition || '',
+        width => $self->width || 0,
+        height => $self->height || 0,
+    );
+    my $html = $builder->build_html();
+    if( !$html ) {
+        system "perldoc App::revealup::cli::serve";
+        exit;
     }
 
-    if($_theme) {
-        $_theme .= '.css' if $_theme !~ m!.+\.css$!;
-        $_theme_path = path('.', $_theme);
-    }
-    my $html = $self->render($filename);
     my $app = $self->app($html);
     my $runner = Plack::Runner->new();
     $runner->parse_options("--no-default-middleware");
-    $runner->set_options(port => $_plack_port);
-    $runner->run($app) if !$_dry_run;
-}
-
-sub render {
-    my ($self, $filename) = @_;
-    my $template_dir = App::revealup::util::share_path([qw/share templates/]);
-    my $template = $template_dir->child('slide.html.mt');
-    my $content = $template->slurp_utf8();
-    my $html = render_mt(
-        $content,
-        $filename,
-        $_theme_path,
-        $_transition,
-        $_size )->as_string();
-    return $html;
+    $runner->set_options(port => $self->plack_port);
+    $runner->run($app) if !$self->dry_run
 }
 
 sub app {
@@ -73,12 +68,12 @@ sub app {
 
         my $path;
         # theme
-        if($_theme_path && $env->{PATH_INFO} =~ m!$_theme_path$!){
-            if($_theme_path->exists) {
-                $path = path('.', $_theme_path);
+        if($self->theme_path && $env->{PATH_INFO} =~ m!${self->theme_path}$!){
+            if($self->theme_path->exists) {
+                $path = path('.', $self->theme_path);
             }else{
                 my $reveal_theme_path = App::revealup::util::share_path([qw/share revealjs css theme/]);
-                $path = $reveal_theme_path->child($_theme_path->basename);
+                $path = $reveal_theme_path->child($self->theme_path->basename);
             }
             return App::revealup::util::path_to_res($path) if $path->exists;
         }
@@ -86,10 +81,10 @@ sub app {
         $path = path('.', $env->{PATH_INFO});
         return App::revealup::util::path_to_res($path) if $path->exists;
 
-        my $reveal_dir = App::revealup::util::share_path([qw/share revealjs/]);
+        my $reveal_dir = App::revealup::util::share_path([qw/share/]);
         $path = $reveal_dir->child($env->{PATH_INFO});
         return App::revealup::util::path_to_res($path) if $path->exists;
-        warn "[Warning] $path does not exist.\n";
+        App::revealup::util::warn("$path does not exist");
         return [
             404,
             ['Content-Type' => 'text/plain'],
@@ -108,33 +103,33 @@ __END__
 
 =head1 DESCRIPTION
 
-I<serve> command makes your markdown texts as a HTTP Web application for slide show.
+C<serve> command makes your markdown texts as a HTTP Web application for slide show.
 Run C<revealup serve> the with markdown filename and options.
 And with your browser access such url I<http://localhost:5000/>.
 
-=head1 Options
+=head2 Options
 
-=head2 -p or --port
+=head3 C<-p> or C<--port>
 
 HTTP port number
 
-=head2 --theme
+=head3 C<--theme>
 
 CSS filename or original CSS file path. The reveal.js default CSS filenames are below.
 
     beige.css / blood.css / default.css / moon.css / night.css / serif.css / simple.css / sky.css / solarized.css
 
-=head2 --transition
+=head3 C<--transition>
 
 Trasition effects for slides.
 
     default / cube / page / concave / zoom / linear / fade / none
 
-=head2 width
+=head3 C<--width>
 
 Width of a slide's size. Default is 960.
 
-=head2 height
+=head3 C<--height>
 
 Height of a slide's size. Default is 700.
 
