@@ -6,8 +6,9 @@ use File::ShareDir qw/dist_dir/;
 use Path::Tiny qw/path/;
 use Getopt::Long qw//;
 use MIME::Types qw//;
+use Term::ANSIColor;
 
-our @EXPORT = qw/path_to_res share_path parse_options/;
+our @EXPORT = qw/path_to_res share_path parse_options error warn info/;
 
 sub parse_options {
     my ($args, @options) = @_;
@@ -39,4 +40,32 @@ sub share_path {
     return path($dist_dir, @$p);
 }
 
+sub error {
+    my $message = shift;
+    print "[";
+    print color 'red';
+    print "Error";
+    print color 'reset';
+    print "] $message\n";
+    exit;
+}
+
+sub warn {
+    my $message = shift;
+    print "[";
+    print color 'yellow';
+    print "Warn";
+    print color 'reset';
+    print "] $message\n";
+}
+
+sub info {
+    my $message = shift;
+    print "[";
+    print color 'green';
+    print "Info";
+    print color 'reset';
+    print "] $message\n";
+}
+
 1;
